<?php

namespace SimpleSAML\Error;

/**
 * Class ProxyCountExceeded
 *
 * @deprecated This class has been deprecated and will be removed in SimpleSAMLphp 2.0. Please use
 * \SimpleSAML\Module\saml\Error\ProxyCountExceeded instead.
 *
 * @see \SimpleSAML\Module\saml\Error\ProxyCountExceeded
 */

class ProxyCountExceeded extends Exception
{
}
